{-----------------------------------------------------------------------------
The contents of this file are subject to the Mozilla Public License
Version 1.1 (the "License"); you may not use this file except in compliance
with the License. You may obtain a copy of the License at
http://www.mozilla.org/MPL/MPL-1.1.html

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either expressed or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is: JvAlignListbox.PAS, released on 2000-11-22.

The Initial Developer of the Original Code is Peter Below <100113.1101@compuserve.com>
Portions created by Peter Below are Copyright (C) 2000 Peter Below.
All Rights Reserved.

Contributor(s): ______________________________________.

Last Modified: 2000-mm-dd

You may retrieve the latest version of this file at the Project JEDI home page,
located at http://www.delphi-jedi.org

Known Issues:
-----------------------------------------------------------------------------}
{$A+,B-,C+,D+,E-,F-,G+,H+,I+,J+,K-,L+,M-,N+,O+,P+,Q-,R-,S-,T-,U-,V+,W-,X+,Y+,Z1}
{$I JEDI.INC}


unit JvSizeablePanel;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls;

// *** Important to include this constant showing your version #
const
  TJvComponent_VERSION      = '5.01';


type
  TJvSizeablePanel = class(TPanel)
  private
    FDragging: Boolean;
    FLastPos: TPoint;
    function GetAboutMe: string;
    procedure SetAboutMe(const Value: string);
  protected
    Procedure Paint; override;
    Procedure MouseDown( Button: TMouseButton; Shift: TShiftState;
                         X, Y: Integer ); override;
    Procedure MouseMove( Shift: TShiftState; X, Y: Integer ); override;
    Procedure MouseUp( Button: TMouseButton; Shift: TShiftState;
                       X, Y: Integer ); override;
  public
    { Public declarations }
  published
    { Published declarations }
    property AboutMe: string read GetAboutMe write SetAboutMe stored False;
  end;

implementation


function TJvSizeablePanel.GetAboutMe: string;
begin
  Result := 'Version: '+TJvComponent_VERSION;
end;

procedure TJvSizeablePanel.MouseDown(Button: TMouseButton; Shift: TShiftState; X,
  Y: Integer);
begin
  If (Button = mbLeft) and
     ((Width - x ) < 10) and
     ((Height - y ) < 10)
  Then Begin
    FDragging := TRue;
    FLastPos := Point( x, y );
    MouseCapture := true;
    Screen.cursor := crSizeNWSE;
  End
  Else
    inherited;
end;

procedure TJvSizeablePanel.MouseMove(Shift: TShiftState; X, Y: Integer);
var
  r: TRect;
begin
  If FDragging Then Begin
    r:= BoundsRect;
    SetBounds( r.left, r.top,
               r.right - r.left + X - FlastPos.X,
               r.bottom - r.top + Y - Flastpos.Y );
    FLastPos := Point( x, y );
  End
  Else Begin
    inherited;
    If ((Width - x ) < 10) and ((Height - y ) < 10) Then
      Cursor := crSizeNWSE
    Else
      Cursor := crDefault;  

  End;
end;

procedure TJvSizeablePanel.MouseUp(Button: TMouseButton; Shift: TShiftState; X,
  Y: Integer);
begin
  If FDragging Then Begin
    FDragging := False;
    MouseCapture := false;
    Screen.Cursor := crDefault;
  End
  Else
    inherited;
end;

procedure TJvSizeablePanel.Paint;
var
  x, y: Integer;
begin
  inherited;
  Canvas.Font.Name := 'Marlett';
  Canvas.Font.Size := 10;
  Canvas.Brush.Style := bsClear;
  x:= clientwidth - canvas.textwidth('o');
  y:= clientheight - canvas.textheight('o');
  canvas.textout( x, y, 'o' );
end;


procedure TJvSizeablePanel.SetAboutMe(const Value: string);
begin

end;

end.
